@@ -1,34 +1,35 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="2.0" language="de" sourcelanguage="">
+<!DOCTYPE TS>
+<TS version="2.1" language="de">
 <context>
     <name>AskBeforeQuit</name>
     <message>
-        <location filename="../../mainwindow.py" line="327"/>
+        <location filename="../../mainwindow.py" line="329"/>
         <source>About to quit but session {} still open</source>
         <translation>Programm soll beendet werden, aber Session {} ist noch offen</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="328"/>
+        <location filename="../../mainwindow.py" line="330"/>
         <source>Do you want to save?</source>
         <translation>Möchten Sie speichern?</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="329"/>
+        <location filename="../../mainwindow.py" line="331"/>
         <source>About to quit</source>
         <translation>Programm soll beendet werden</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="338"/>
+        <location filename="../../mainwindow.py" line="340"/>
         <source>Don&apos;t Quit</source>
         <translation>Nicht Beenden</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="339"/>
+        <location filename="../../mainwindow.py" line="341"/>
         <source>Save</source>
         <translation>Speichern</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="340"/>
+        <location filename="../../mainwindow.py" line="342"/>
         <source>Discard Changes</source>
         <translation>Änderungen Verwerfen</translation>
     </message>
@@ -58,7 +59,7 @@
     <message>
         <location filename="../../designer/settings.py" line="80"/>
         <source>For advanced users only! Add executable paths to the environment, just for Agordejo and NSM. Changes need a program restart afterwards. If you want your programs in the application launcher use the launcher tab.</source>
-        <translation>Nur für fortgeschrittene Benutzer! Hier absolute Pfade hinzufügen, in denen sich ausführbare Dateien befinden. Diese Einstellungen gelten nur für Agordejo/NSM. Änderungen benötigen einen kompletten Programmneustart. Um Programme zum Schnellstarter hinzuzufügen bitte den Tab &quot;Programmstarter&quot; benutzen.</translation>
+        <translation>Nur für fortgeschrittene Benutzer! Hier absolute Pfade hinzufügen, in denen sich ausführbare Dateien befinden. Diese Einstellungen gelten nur für Agordejo/NSM. Änderungen benötigen einen kompletten Programmneustart. Um Programme zum Schnellstarter hinzuzufügen bitte den Tab &amp;quot;Programmstarter&amp;quot; benutzen.</translation>
     </message>
     <message>
         <location filename="../../designer/settings.py" line="81"/>
@@ -74,17 +75,17 @@
 <context>
     <name>Launcher</name>
     <message>
-        <location filename="../../opensessioncontroller.py" line="451"/>
+        <location filename="../../opensessioncontroller.py" line="444"/>
         <source>Name</source>
         <translation>Name</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="452"/>
+        <location filename="../../opensessioncontroller.py" line="445"/>
         <source>Description</source>
         <translation>Beschreibung</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="453"/>
+        <location filename="../../opensessioncontroller.py" line="446"/>
         <source>Path</source>
         <translation>Pfad</translation>
     </message>
@@ -94,7 +95,7 @@
     <message>
         <location filename="../../descriptiontextwidget.py" line="43"/>
         <source>Double click to add the client nsm-data to write here.
-Use it for notes, TODO, references etc&#xe2;&#x80;&#xa6;</source>
+Use it for notes, TODO, references etcâ¦</source>
         <translation>Um hier zu schreiben doppelklicken Sie auf dieses Feld (startet nsm-data)
 Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
     </message>
@@ -102,187 +103,182 @@ Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../../designer/mainwindow.py" line="350"/>
+        <location filename="../../designer/mainwindow.py" line="311"/>
         <source>Agordejo</source>
         <translation>Agordejo</translation>
     </message>
     <message>
         <location filename="../../designer/mainwindow.py" line="351"/>
         <source>Start New Session</source>
-        <translation>Neue Session starten</translation>
+        <translation type="obsolete">Neue Session starten</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="352"/>
-        <source>Session Name Goes Here</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../../designer/mainwindow.py" line="390"/>
+        <location filename="../../designer/mainwindow.py" line="354"/>
         <source>Save</source>
         <translation>Speichern</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="394"/>
+        <location filename="../../designer/mainwindow.py" line="358"/>
         <source>Save and Close</source>
         <translation>Speichern und Schließen</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="363"/>
+        <location filename="../../designer/mainwindow.py" line="326"/>
         <source>Session Notes</source>
         <translation>Session Notizen</translation>
     </message>
     <message>
         <location filename="../../designer/mainwindow.py" line="357"/>
         <source>Quick View</source>
-        <translation>Schnelle Ansicht</translation>
+        <translation type="obsolete">Schnelle Ansicht</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="358"/>
+        <location filename="../../designer/mainwindow.py" line="317"/>
         <source>New</source>
         <translation>Neu</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="359"/>
+        <location filename="../../designer/mainwindow.py" line="319"/>
         <source>Load Selected</source>
         <translation>Lade Ausgewählte</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="360"/>
+        <location filename="../../designer/mainwindow.py" line="323"/>
         <source>Tree View</source>
         <translation>Baumansicht</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="361"/>
+        <location filename="../../designer/mainwindow.py" line="324"/>
         <source>Double-click to load program</source>
         <translation>Doppelklick um Programm zu starten</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="362"/>
+        <location filename="../../designer/mainwindow.py" line="325"/>
         <source>In current session</source>
         <translation>Momentan in der Session</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="364"/>
+        <location filename="../../designer/mainwindow.py" line="327"/>
         <source>Full View</source>
         <translation>Volle Ansicht</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="367"/>
+        <location filename="../../designer/mainwindow.py" line="330"/>
         <source>JACK</source>
         <translation>JACK</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="368"/>
+        <location filename="../../designer/mainwindow.py" line="331"/>
         <source>version and running</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="369"/>
+        <location filename="../../designer/mainwindow.py" line="332"/>
         <source>NSM Server Mode</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="370"/>
+        <location filename="../../designer/mainwindow.py" line="333"/>
         <source>Self-started, connected to, environment var</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="371"/>
+        <location filename="../../designer/mainwindow.py" line="334"/>
         <source>NSM Url</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="372"/>
+        <location filename="../../designer/mainwindow.py" line="335"/>
         <source>osc.upd ip port</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="373"/>
+        <location filename="../../designer/mainwindow.py" line="336"/>
         <source>Session Root</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="374"/>
+        <location filename="../../designer/mainwindow.py" line="337"/>
         <source>/home/usr/NSM Sessions</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="375"/>
+        <location filename="../../designer/mainwindow.py" line="338"/>
         <source>Program Database</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="376"/>
+        <location filename="../../designer/mainwindow.py" line="339"/>
         <source>Last Updated</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="378"/>
+        <location filename="../../designer/mainwindow.py" line="341"/>
         <source>Information</source>
         <translation>Information</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="379"/>
+        <location filename="../../designer/mainwindow.py" line="342"/>
         <source>Processing</source>
         <translation>Arbeitet</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="380"/>
+        <location filename="../../designer/mainwindow.py" line="344"/>
         <source>Control</source>
         <translation>Steuerung</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="381"/>
+        <location filename="../../designer/mainwindow.py" line="345"/>
         <source>SessionName</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="382"/>
+        <location filename="../../designer/mainwindow.py" line="346"/>
         <source>ClientNameId</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="383"/>
+        <location filename="../../designer/mainwindow.py" line="347"/>
         <source>Quit</source>
         <translation>Beenden</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="384"/>
+        <location filename="../../designer/mainwindow.py" line="348"/>
         <source>Ctrl+Shift+Q</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="385"/>
+        <location filename="../../designer/mainwindow.py" line="349"/>
         <source>About</source>
         <translation>Über</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="414"/>
+        <location filename="../../designer/mainwindow.py" line="378"/>
         <source>Manual</source>
         <translation>Handbuch</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="386"/>
+        <location filename="../../designer/mainwindow.py" line="350"/>
         <source>Hide in System Tray</source>
         <translation>Minimieren zum Tray</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="387"/>
+        <location filename="../../designer/mainwindow.py" line="351"/>
         <source>Ctrl+Q</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="388"/>
+        <location filename="../../designer/mainwindow.py" line="352"/>
         <source>Add Client (Prompt)</source>
         <translation>Programm hinzufügen (Prompt)</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="389"/>
+        <location filename="../../designer/mainwindow.py" line="353"/>
         <source>A</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="391"/>
+        <location filename="../../designer/mainwindow.py" line="355"/>
         <source>Ctrl+S</source>
         <translation></translation>
     </message>
@@ -292,12 +288,12 @@ Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
         <translation type="obsolete">Speichern unter</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="393"/>
+        <location filename="../../designer/mainwindow.py" line="357"/>
         <source>Ctrl+Shift+S</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="395"/>
+        <location filename="../../designer/mainwindow.py" line="359"/>
         <source>Ctrl+W</source>
         <translation></translation>
     </message>
@@ -307,121 +303,199 @@ Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
         <translation type="obsolete">Abbrechen</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="397"/>
+        <location filename="../../designer/mainwindow.py" line="361"/>
         <source>Ctrl+Shift+W</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="398"/>
+        <location filename="../../designer/mainwindow.py" line="362"/>
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="399"/>
+        <location filename="../../designer/mainwindow.py" line="363"/>
         <source>Alt+O</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="400"/>
+        <location filename="../../designer/mainwindow.py" line="364"/>
         <source>Resume</source>
         <translation>Fortführen</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="401"/>
+        <location filename="../../designer/mainwindow.py" line="365"/>
         <source>Alt+R</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="402"/>
+        <location filename="../../designer/mainwindow.py" line="366"/>
         <source>Save separately</source>
         <translation>Seperat speichern</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="403"/>
+        <location filename="../../designer/mainwindow.py" line="367"/>
         <source>Alt+S</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="404"/>
+        <location filename="../../designer/mainwindow.py" line="368"/>
         <source>Remove</source>
         <translation>Entfernen</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="405"/>
+        <location filename="../../designer/mainwindow.py" line="369"/>
         <source>Alt+X</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="406"/>
+        <location filename="../../designer/mainwindow.py" line="370"/>
         <source>Toggle Visible</source>
         <translation>Sichtbarkeit umschalten</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="407"/>
+        <location filename="../../designer/mainwindow.py" line="371"/>
         <source>Alt+T</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="408"/>
+        <location filename="../../designer/mainwindow.py" line="372"/>
         <source>Show All Clients</source>
         <translation>Zeige alle Clients</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="409"/>
+        <location filename="../../designer/mainwindow.py" line="373"/>
         <source>Hide All Clients</source>
         <translation>Verstecke alle Clients</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="410"/>
+        <location filename="../../designer/mainwindow.py" line="374"/>
         <source>Rebuild Program Database</source>
         <translation>Programmdatenbank generieren</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="411"/>
+        <location filename="../../designer/mainwindow.py" line="375"/>
         <source>Rename</source>
         <translation>Umbenennen</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="412"/>
+        <location filename="../../designer/mainwindow.py" line="376"/>
         <source>F2</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="413"/>
+        <location filename="../../designer/mainwindow.py" line="377"/>
         <source>Settings</source>
         <translation>Einstellungen</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="392"/>
+        <location filename="../../designer/mainwindow.py" line="356"/>
         <source>Save and Clone under different name</source>
         <translation>Speichern und mit anderem Namen neu öffnen</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="396"/>
+        <location filename="../../designer/mainwindow.py" line="360"/>
         <source>Close without Save (&quot;Abort&quot;)</source>
-        <translation>Schließen ohne zu Speichern (&quot;Abbrechen&quot;)</translation>
+        <translation>Schließen ohne zu Speichern (&amp;quot;Abbrechen&amp;quot;)</translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="312"/>
+        <source>Global Playback Controls</source>
+        <translation>Globaler Zugriff aufs Playback</translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="313"/>
+        <source>PlayPause</source>
+        <translation>PlayPause</translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="314"/>
+        <source>Rewind</source>
+        <translation>Rewind</translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="315"/>
+        <source> time-placeholder</source>
+        <translation> time-placeholder</translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="316"/>
+        <source> min</source>
+        <translation> min</translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="318"/>
+        <source>Quick New</source>
+        <translation>Schnellstart Neu</translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="320"/>
+        <source>Rename Selected</source>
+        <translation>Namen ändern</translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="321"/>
+        <source>Copy Selected</source>
+        <translation>Kopieren</translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="322"/>
+        <source>Delete Selected</source>
+        <translation>Löschen</translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="320"/>
+        <source>Remove Lock</source>
+        <translation type="obsolete">Lock aufheben</translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="343"/>
+        <source>I understand that I will need to resolve this problem on my own!</source>
+        <translation>Ich verstehe, dass ich dieses Problem selbst lösen muss!</translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="379"/>
+        <source>News and Changelog</source>
+        <translation>News und Changelog</translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="380"/>
+        <source>Split Session View the other way</source>
+        <translation>Sessionfenster anders aufteilen</translation>
+    </message>
+</context>
+<context>
+    <name>NOOPEngineStrings</name>
+    <message>
+        <location filename="../../mainwindow.py" line="134"/>
+        <source>ERROR! Copied session data is different from source session. Please check you data!</source>
+        <translation>ERROR! Kopierte Daten der Session unterscheiden sich von der Ursprünlinglichen! Bitte überprüfen Sie die Integrität der kopierten Daten!</translation>
+    </message>
+    <message>
+        <location filename="../../mainwindow.py" line="135"/>
+        <source>Veryfying file-integrity. This may take a while...</source>
+        <translation>Überprüfe Integrität der Dateien. Bitte haben Sie etwas Geduld...</translation>
     </message>
 </context>
 <context>
     <name>NewSession</name>
     <message>
-        <location filename="../../designer/newsession.py" line="47"/>
+        <location filename="../../designer/newsession.py" line="48"/>
         <source>Dialog</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/newsession.py" line="48"/>
+        <location filename="../../designer/newsession.py" line="49"/>
         <source>New Session Name</source>
         <translation>Name für neue Session</translation>
     </message>
     <message>
-        <location filename="../../designer/newsession.py" line="49"/>
+        <location filename="../../designer/newsession.py" line="50"/>
         <source>Save JACK Connections
 (adds clients &apos;jackpatch&apos;)</source>
         <translation>Speichere JACK-Verbindungen (mit Client &apos;jackpatch&apos;)</translation>
     </message>
     <message>
-        <location filename="../../designer/newsession.py" line="51"/>
+        <location filename="../../designer/newsession.py" line="52"/>
         <source>Client Renaming and Session Notes
 (adds client &apos;nsm-data&apos;)</source>
         <translation>Umbenennen und Session-Notitzen aktivieren (mit Client &apos;nsm-data&apos;)</translation>
@@ -430,12 +504,12 @@ Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
 <context>
     <name>OpenSession</name>
     <message>
-        <location filename="../../opensessioncontroller.py" line="97"/>
+        <location filename="../../opensessioncontroller.py" line="98"/>
         <source>not saved</source>
         <translation>ungespeichert</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="99"/>
+        <location filename="../../opensessioncontroller.py" line="100"/>
         <source>clean</source>
         <translation>clean</translation>
     </message>
@@ -445,32 +519,32 @@ Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
         <translation type="obsolete">(Befehl nicht gefunden)</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="159"/>
+        <location filename="../../opensessioncontroller.py" line="160"/>
         <source>Name</source>
         <translation>Name</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="160"/>
+        <location filename="../../opensessioncontroller.py" line="161"/>
         <source>Label</source>
         <translation>Label</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="161"/>
+        <location filename="../../opensessioncontroller.py" line="162"/>
         <source>Status</source>
         <translation>Status</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="162"/>
+        <location filename="../../opensessioncontroller.py" line="163"/>
         <source>Visible</source>
         <translation>Sichtbarkeit</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="163"/>
+        <location filename="../../opensessioncontroller.py" line="164"/>
         <source>Changes</source>
         <translation>Änderungen</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="164"/>
+        <location filename="../../opensessioncontroller.py" line="165"/>
         <source>ID</source>
         <translation>ID</translation>
     </message>
@@ -541,12 +615,12 @@ Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
     <message>
         <location filename="../../addclientprompt.py" line="68"/>
         <source>Command not accepted!&lt;br&gt;Parameters, --switches and relative paths are not allowed.&lt;br&gt;Use nsm-proxy or write a starter-script instead.</source>
-        <translation type="obsolete">Befehl nicht akzeptiert!&lt;br&gt;Parameter, --schalter und relative Pfade sind nicht erlaubt.&lt;br&gt;Benutzen Sie stattdessen ein Programm wie nsm-proxy oder schreiben sie selbst ein Starterscript.</translation>
+        <translation type="obsolete">Befehl nicht akzeptiert!&amp;lt;br&amp;gt;Parameter, --schalter und relative Pfade sind nicht erlaubt.&amp;lt;br&amp;gt;Benutzen Sie stattdessen ein Programm wie nsm-proxy oder schreiben sie selbst ein Starterscript.</translation>
     </message>
     <message>
         <location filename="../../addclientprompt.py" line="70"/>
         <source>Command not found or not accepted!&lt;br&gt;Parameters, --switches and relative paths are not allowed.&lt;br&gt;Use nsm-proxy or write a starter-script instead.</source>
-        <translation>Befehl nicht gefunden oder nicht akzeptiert!&lt;br&gt;Parameter, --schalter und relative Pfade sind nicht erlaubt.&lt;br&gt;Benutzen Sie stattdessen ein Programm wie nsm-proxy oder schreiben sie selbst ein Starterscript.</translation>
+        <translation>Befehl nicht gefunden oder nicht akzeptiert!&amp;lt;br&amp;gt;Parameter, --schalter und relative Pfade sind nicht erlaubt.&amp;lt;br&amp;gt;Benutzen Sie stattdessen ein Programm wie nsm-proxy oder schreiben sie selbst ein Starterscript.</translation>
     </message>
 </context>
 <context>
@@ -582,45 +656,63 @@ Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
         <translation>Pfad</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="247"/>
+        <location filename="../../sessiontreecontroller.py" line="254"/>
         <source>About to delete Session {}</source>
         <translation>Session {} soll gelöscht werden</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="246"/>
+        <location filename="../../sessiontreecontroller.py" line="253"/>
         <source>All files in the project directory will be irreversibly deleted.</source>
         <translation>Alle Dateien aus diesem Projektverzeichnis werden unwiederbringlich gelöscht.</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="255"/>
+        <location filename="../../sessiontreecontroller.py" line="262"/>
         <source>Keep Session</source>
         <translation>Session behalten</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="256"/>
+        <location filename="../../sessiontreecontroller.py" line="263"/>
         <source>Delete!</source>
         <translation>Löschen!</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="272"/>
+        <location filename="../../sessiontreecontroller.py" line="279"/>
         <source>Copy Session</source>
         <translation>Session kopieren</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="275"/>
+        <location filename="../../sessiontreecontroller.py" line="285"/>
         <source>Force Lock Removal</source>
-        <translation>Lockdatei Aufhebung erzwingen</translation>
+        <translation type="obsolete">Lockdatei Aufhebung erzwingen</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="277"/>
+        <location filename="../../sessiontreecontroller.py" line="282"/>
         <source>Rename Session</source>
         <translation>Session umbennen</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="279"/>
+        <location filename="../../sessiontreecontroller.py" line="284"/>
         <source>Delete Session</source>
         <translation>Session löschen</translation>
     </message>
+    <message>
+        <location filename="../../sessiontreecontroller.py" line="342"/>
+        <source>Copying {} to {}</source>
+        <translation>Kopiere {} nach {}</translation>
+    </message>
+</context>
+<context>
+    <name>TemplateChangelog</name>
+    <message>
+        <location filename="../../changelog.py" line="49"/>
+        <source>Changelog</source>
+        <translation>Changelog</translation>
+    </message>
+    <message>
+        <location filename="../../changelog.py" line="50"/>
+        <source>The Changelog is only available in English.</source>
+        <translation>Den Changelog gibt es nur auf Englisch.</translation>
+    </message>
 </context>
 <context>
     <name>TemplateUserManual</name>
@@ -648,40 +740,53 @@ Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
 <context>
     <name>TrayIcon</name>
     <message>
-        <location filename="../../systemtray.py" line="64"/>
+        <location filename="../../systemtray.py" line="84"/>
         <source>Hide/Show Agordejo</source>
         <translation>Verstecke/Zeige Agordejo</translation>
     </message>
     <message>
-        <location filename="../../systemtray.py" line="78"/>
+        <location filename="../../systemtray.py" line="103"/>
         <source>Save &amp;&amp; Quit Agordejo</source>
         <translation>Abbrechen und Agordejo Beenden</translation>
     </message>
     <message>
-        <location filename="../../systemtray.py" line="85"/>
+        <location filename="../../systemtray.py" line="110"/>
         <source>Quit </source>
         <translation>Beenden </translation>
     </message>
     <message>
-        <location filename="../../systemtray.py" line="70"/>
+        <location filename="../../systemtray.py" line="89"/>
         <source>Add Client (Prompt)</source>
         <translation>Programm hinzufügen (Prompt)</translation>
     </message>
     <message>
-        <location filename="../../systemtray.py" line="79"/>
+        <location filename="../../systemtray.py" line="104"/>
         <source>Close without Saving &amp;&amp; Quit Agordejo</source>
         <translation>Schließen ohne zu Speichern &amp;&amp; Agordejo beenden</translation>
     </message>
+    <message>
+        <location filename="../../systemtray.py" line="95"/>
+        <source>Toggle Client Visibility</source>
+        <translation>Sichtbarkeit umschalten</translation>
+    </message>
+</context>
+<context>
+    <name>WaitDialog</name>
+    <message>
+        <location filename="../../waitdialog.py" line="69"/>
+        <source>Please confirm with a click on the button at the bottom.</source>
+        <translation>Bitte bestätigen Sie durch einen Klick auf den Knopf unten.</translation>
+    </message>
 </context>
 <context>
     <name>mainWindow</name>
     <message>
-        <location filename="../../mainwindow.py" line="208"/>
+        <location filename="../../mainwindow.py" line="203"/>
         <source>Agordejo ready</source>
         <translation>Agordejo ist bereit</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="243"/>
+        <location filename="../../mainwindow.py" line="238"/>
         <source>Another GUI tried to launch.</source>
         <translation>Es wurde versucht eine weitere GUI zu starten.</translation>
     </message>
@@ -689,8 +794,17 @@ Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
         <location filename="../../mainwindow.py" line="287"/>
         <source>Updating Program Database.
 Thank you for your patience.</source>
-        <translation>Programmdatenbank wird aktualisiert.
+        <translation type="obsolete">Programmdatenbank wird aktualisiert.
 Vielen Dank für ihre Geduld.</translation>
     </message>
+    <message>
+        <location filename="../../mainwindow.py" line="277"/>
+        <source>Updating Program Database.
+Thank you for your patience.
+If progress freezes please kill and restart the whole program.</source>
+        <translation>Programmdatenbank wird aktualisiert.
+Vielen Dank für ihre Geduld.
+Wenn der Prozess eingeforen ist erzwingen Sie bitte die Beendung des Programms und starten es erneut. Ihre Daten sind sicher.</translation>
+    </message>
 </context>
 </TS>
