@@ -1,34 +1,35 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="2.0" language="it" sourcelanguage="">
+<!DOCTYPE TS>
+<TS version="2.1" language="it">
 <context>
     <name>AskBeforeQuit</name>
     <message>
-        <location filename="../../mainwindow.py" line="327"/>
+        <location filename="../../mainwindow.py" line="329"/>
         <source>About to quit but session {} still open</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="328"/>
+        <location filename="../../mainwindow.py" line="330"/>
         <source>Do you want to save?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="329"/>
+        <location filename="../../mainwindow.py" line="331"/>
         <source>About to quit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="338"/>
+        <location filename="../../mainwindow.py" line="340"/>
         <source>Don&apos;t Quit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="339"/>
+        <location filename="../../mainwindow.py" line="341"/>
         <source>Save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="340"/>
+        <location filename="../../mainwindow.py" line="342"/>
         <source>Discard Changes</source>
         <translation type="unfinished"></translation>
     </message>
@@ -74,17 +75,17 @@
 <context>
     <name>Launcher</name>
     <message>
-        <location filename="../../opensessioncontroller.py" line="451"/>
+        <location filename="../../opensessioncontroller.py" line="444"/>
         <source>Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="452"/>
+        <location filename="../../opensessioncontroller.py" line="445"/>
         <source>Description</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="453"/>
+        <location filename="../../opensessioncontroller.py" line="446"/>
         <source>Path</source>
         <translation type="unfinished"></translation>
     </message>
@@ -101,316 +102,374 @@ Use it for notes, TODO, references etc&#xe2;&#x80;&#xa6;</source>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../../designer/mainwindow.py" line="350"/>
+        <location filename="../../designer/mainwindow.py" line="311"/>
         <source>Agordejo</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="351"/>
-        <source>Start New Session</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../designer/mainwindow.py" line="352"/>
-        <source>Session Name Goes Here</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../designer/mainwindow.py" line="390"/>
+        <location filename="../../designer/mainwindow.py" line="354"/>
         <source>Save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="394"/>
+        <location filename="../../designer/mainwindow.py" line="358"/>
         <source>Save and Close</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="363"/>
+        <location filename="../../designer/mainwindow.py" line="326"/>
         <source>Session Notes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="357"/>
-        <source>Quick View</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../designer/mainwindow.py" line="358"/>
+        <location filename="../../designer/mainwindow.py" line="317"/>
         <source>New</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="359"/>
+        <location filename="../../designer/mainwindow.py" line="319"/>
         <source>Load Selected</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="360"/>
+        <location filename="../../designer/mainwindow.py" line="323"/>
         <source>Tree View</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="361"/>
+        <location filename="../../designer/mainwindow.py" line="324"/>
         <source>Double-click to load program</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="362"/>
+        <location filename="../../designer/mainwindow.py" line="325"/>
         <source>In current session</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="364"/>
+        <location filename="../../designer/mainwindow.py" line="327"/>
         <source>Full View</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="367"/>
+        <location filename="../../designer/mainwindow.py" line="330"/>
         <source>JACK</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="368"/>
+        <location filename="../../designer/mainwindow.py" line="331"/>
         <source>version and running</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="369"/>
+        <location filename="../../designer/mainwindow.py" line="332"/>
         <source>NSM Server Mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="370"/>
+        <location filename="../../designer/mainwindow.py" line="333"/>
         <source>Self-started, connected to, environment var</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="371"/>
+        <location filename="../../designer/mainwindow.py" line="334"/>
         <source>NSM Url</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="372"/>
+        <location filename="../../designer/mainwindow.py" line="335"/>
         <source>osc.upd ip port</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="373"/>
+        <location filename="../../designer/mainwindow.py" line="336"/>
         <source>Session Root</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="374"/>
+        <location filename="../../designer/mainwindow.py" line="337"/>
         <source>/home/usr/NSM Sessions</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="375"/>
+        <location filename="../../designer/mainwindow.py" line="338"/>
         <source>Program Database</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="376"/>
+        <location filename="../../designer/mainwindow.py" line="339"/>
         <source>Last Updated</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="378"/>
+        <location filename="../../designer/mainwindow.py" line="341"/>
         <source>Information</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="379"/>
+        <location filename="../../designer/mainwindow.py" line="342"/>
         <source>Processing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="380"/>
+        <location filename="../../designer/mainwindow.py" line="344"/>
         <source>Control</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="381"/>
+        <location filename="../../designer/mainwindow.py" line="345"/>
         <source>SessionName</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="382"/>
+        <location filename="../../designer/mainwindow.py" line="346"/>
         <source>ClientNameId</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="383"/>
+        <location filename="../../designer/mainwindow.py" line="347"/>
         <source>Quit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="384"/>
+        <location filename="../../designer/mainwindow.py" line="348"/>
         <source>Ctrl+Shift+Q</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="385"/>
+        <location filename="../../designer/mainwindow.py" line="349"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="386"/>
+        <location filename="../../designer/mainwindow.py" line="350"/>
         <source>Hide in System Tray</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="387"/>
+        <location filename="../../designer/mainwindow.py" line="351"/>
         <source>Ctrl+Q</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="388"/>
+        <location filename="../../designer/mainwindow.py" line="352"/>
         <source>Add Client (Prompt)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="389"/>
+        <location filename="../../designer/mainwindow.py" line="353"/>
         <source>A</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="391"/>
+        <location filename="../../designer/mainwindow.py" line="355"/>
         <source>Ctrl+S</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="392"/>
+        <location filename="../../designer/mainwindow.py" line="356"/>
         <source>Save and Clone under different name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="393"/>
+        <location filename="../../designer/mainwindow.py" line="357"/>
         <source>Ctrl+Shift+S</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="395"/>
+        <location filename="../../designer/mainwindow.py" line="359"/>
         <source>Ctrl+W</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="396"/>
+        <location filename="../../designer/mainwindow.py" line="360"/>
         <source>Close without Save (&quot;Abort&quot;)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="397"/>
+        <location filename="../../designer/mainwindow.py" line="361"/>
         <source>Ctrl+Shift+W</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="398"/>
+        <location filename="../../designer/mainwindow.py" line="362"/>
         <source>Stop</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="399"/>
+        <location filename="../../designer/mainwindow.py" line="363"/>
         <source>Alt+O</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="400"/>
+        <location filename="../../designer/mainwindow.py" line="364"/>
         <source>Resume</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="401"/>
+        <location filename="../../designer/mainwindow.py" line="365"/>
         <source>Alt+R</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="402"/>
+        <location filename="../../designer/mainwindow.py" line="366"/>
         <source>Save separately</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="403"/>
+        <location filename="../../designer/mainwindow.py" line="367"/>
         <source>Alt+S</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="404"/>
+        <location filename="../../designer/mainwindow.py" line="368"/>
         <source>Remove</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="405"/>
+        <location filename="../../designer/mainwindow.py" line="369"/>
         <source>Alt+X</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="406"/>
+        <location filename="../../designer/mainwindow.py" line="370"/>
         <source>Toggle Visible</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="407"/>
+        <location filename="../../designer/mainwindow.py" line="371"/>
         <source>Alt+T</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="408"/>
+        <location filename="../../designer/mainwindow.py" line="372"/>
         <source>Show All Clients</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="409"/>
+        <location filename="../../designer/mainwindow.py" line="373"/>
         <source>Hide All Clients</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="410"/>
+        <location filename="../../designer/mainwindow.py" line="374"/>
         <source>Rebuild Program Database</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="411"/>
+        <location filename="../../designer/mainwindow.py" line="375"/>
         <source>Rename</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="412"/>
+        <location filename="../../designer/mainwindow.py" line="376"/>
         <source>F2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="413"/>
+        <location filename="../../designer/mainwindow.py" line="377"/>
         <source>Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="414"/>
+        <location filename="../../designer/mainwindow.py" line="378"/>
         <source>Manual</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="312"/>
+        <source>Global Playback Controls</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="313"/>
+        <source>PlayPause</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="314"/>
+        <source>Rewind</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="315"/>
+        <source> time-placeholder</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="316"/>
+        <source> min</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="318"/>
+        <source>Quick New</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="320"/>
+        <source>Rename Selected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="321"/>
+        <source>Copy Selected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="322"/>
+        <source>Delete Selected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="343"/>
+        <source>I understand that I will need to resolve this problem on my own!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="379"/>
+        <source>News and Changelog</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="380"/>
+        <source>Split Session View the other way</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>NOOPEngineStrings</name>
+    <message>
+        <location filename="../../mainwindow.py" line="134"/>
+        <source>ERROR! Copied session data is different from source session. Please check you data!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../mainwindow.py" line="135"/>
+        <source>Veryfying file-integrity. This may take a while...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>NewSession</name>
     <message>
-        <location filename="../../designer/newsession.py" line="47"/>
+        <location filename="../../designer/newsession.py" line="48"/>
         <source>Dialog</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/newsession.py" line="48"/>
+        <location filename="../../designer/newsession.py" line="49"/>
         <source>New Session Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/newsession.py" line="49"/>
+        <location filename="../../designer/newsession.py" line="50"/>
         <source>Save JACK Connections
 (adds clients &apos;jackpatch&apos;)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/newsession.py" line="51"/>
+        <location filename="../../designer/newsession.py" line="52"/>
         <source>Client Renaming and Session Notes
 (adds client &apos;nsm-data&apos;)</source>
         <translation type="unfinished"></translation>
@@ -419,42 +478,42 @@ Use it for notes, TODO, references etc&#xe2;&#x80;&#xa6;</source>
 <context>
     <name>OpenSession</name>
     <message>
-        <location filename="../../opensessioncontroller.py" line="97"/>
+        <location filename="../../opensessioncontroller.py" line="98"/>
         <source>not saved</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="99"/>
+        <location filename="../../opensessioncontroller.py" line="100"/>
         <source>clean</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="159"/>
+        <location filename="../../opensessioncontroller.py" line="160"/>
         <source>Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="160"/>
+        <location filename="../../opensessioncontroller.py" line="161"/>
         <source>Label</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="161"/>
+        <location filename="../../opensessioncontroller.py" line="162"/>
         <source>Status</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="162"/>
+        <location filename="../../opensessioncontroller.py" line="163"/>
         <source>Visible</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="163"/>
+        <location filename="../../opensessioncontroller.py" line="164"/>
         <source>Changes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="164"/>
+        <location filename="../../opensessioncontroller.py" line="165"/>
         <source>ID</source>
         <translation type="unfinished"></translation>
     </message>
@@ -556,45 +615,58 @@ Use it for notes, TODO, references etc&#xe2;&#x80;&#xa6;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="247"/>
+        <location filename="../../sessiontreecontroller.py" line="254"/>
         <source>About to delete Session {}</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="246"/>
+        <location filename="../../sessiontreecontroller.py" line="253"/>
         <source>All files in the project directory will be irreversibly deleted.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="255"/>
+        <location filename="../../sessiontreecontroller.py" line="262"/>
         <source>Keep Session</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="256"/>
+        <location filename="../../sessiontreecontroller.py" line="263"/>
         <source>Delete!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="272"/>
+        <location filename="../../sessiontreecontroller.py" line="279"/>
         <source>Copy Session</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="275"/>
-        <source>Force Lock Removal</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../sessiontreecontroller.py" line="277"/>
+        <location filename="../../sessiontreecontroller.py" line="282"/>
         <source>Rename Session</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="279"/>
+        <location filename="../../sessiontreecontroller.py" line="284"/>
         <source>Delete Session</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../sessiontreecontroller.py" line="342"/>
+        <source>Copying {} to {}</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>TemplateChangelog</name>
+    <message>
+        <location filename="../../changelog.py" line="49"/>
+        <source>Changelog</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../changelog.py" line="50"/>
+        <source>The Changelog is only available in English.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TemplateUserManual</name>
@@ -622,47 +694,61 @@ Use it for notes, TODO, references etc&#xe2;&#x80;&#xa6;</source>
 <context>
     <name>TrayIcon</name>
     <message>
-        <location filename="../../systemtray.py" line="64"/>
+        <location filename="../../systemtray.py" line="84"/>
         <source>Hide/Show Agordejo</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../systemtray.py" line="70"/>
+        <location filename="../../systemtray.py" line="89"/>
         <source>Add Client (Prompt)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../systemtray.py" line="78"/>
+        <location filename="../../systemtray.py" line="103"/>
         <source>Save &amp;&amp; Quit Agordejo</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../systemtray.py" line="79"/>
+        <location filename="../../systemtray.py" line="104"/>
         <source>Close without Saving &amp;&amp; Quit Agordejo</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../systemtray.py" line="85"/>
+        <location filename="../../systemtray.py" line="110"/>
         <source>Quit </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../systemtray.py" line="95"/>
+        <source>Toggle Client Visibility</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>WaitDialog</name>
+    <message>
+        <location filename="../../waitdialog.py" line="69"/>
+        <source>Please confirm with a click on the button at the bottom.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>mainWindow</name>
     <message>
-        <location filename="../../mainwindow.py" line="208"/>
+        <location filename="../../mainwindow.py" line="203"/>
         <source>Agordejo ready</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="243"/>
+        <location filename="../../mainwindow.py" line="238"/>
         <source>Another GUI tried to launch.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="287"/>
+        <location filename="../../mainwindow.py" line="277"/>
         <source>Updating Program Database.
-Thank you for your patience.</source>
+Thank you for your patience.
+If progress freezes please kill and restart the whole program.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
